==> jc-1.4.0.tar.gz: gnu/java/nio/charset/Provider.h <==
// public final class gnu.java.nio.charset.Provider

// class file dependencies
// @dep_class c93f8dad3a60b851 gnu_java_nio_charset_Provider
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f5e8d54b80f50935 java_nio_charset_spi_CharsetProvider

// header file dependencies
// @dep_header java_nio_charset_spi_CharsetProvider

#include "java/nio/charset/spi/CharsetProvider.h"

#ifndef _JC_gnu_java_nio_charset_Provider_H_
#define _JC_gnu_java_nio_charset_Provider_H_

// Forward structure declarations
struct _jc_gnu_java_nio_charset_Provider$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_Provider$sub_refs	_jc_gnu_java_nio_charset_Provider$sub_refs;
typedef struct _jc_gnu_java_nio_charset_Provider$sub_nonrefs	_jc_gnu_java_nio_charset_Provider$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_Provider$refs	_jc_gnu_java_nio_charset_Provider$refs;
typedef struct _jc_gnu_java_nio_charset_Provider$nonrefs	_jc_gnu_java_nio_charset_Provider$nonrefs;
typedef struct _jc_gnu_java_nio_charset_Provider$object	_jc_gnu_java_nio_charset_Provider$object;

typedef struct _jc_gnu_java_nio_charset_Provider$fields_struct	_jc_gnu_java_nio_charset_Provider$fields_struct;
typedef const struct _jc_gnu_java_nio_charset_Provider$vmethods	_jc_gnu_java_nio_charset_Provider$vmethods;
typedef const struct _jc_gnu_java_nio_charset_Provider$vtable	_jc_gnu_java_nio_charset_Provider$vtable;
typedef const struct _jc_gnu_java_nio_charset_Provider$vtype	_jc_gnu_java_nio_charset_Provider$vtype;

// Class fields structure
struct _jc_gnu_java_nio_charset_Provider$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24nio__24charset__24Provider;
	struct _jc_gnu_java_nio_charset_Provider$object	*singleton;
};
extern _jc_gnu_java_nio_charset_Provider$fields_struct _jc_gnu_java_nio_charset_Provider$class_fields;

// Constructors
extern void _jc_gnu_java_nio_charset_Provider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *);

// Virtual methods
extern void _jc_gnu_java_nio_charset_Provider$method$addCharset$78640163f7ef6b41(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *, struct _jc_java_nio_charset_Charset$object *);
extern struct _jc_java_nio_charset_Charset$object *_jc_gnu_java_nio_charset_Provider$method$charsetForName$cb2dd1cda930620d(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_java_nio_charset_Provider$method$charsets$45ae22f55cf2d149(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_Provider$method_info$addCharset$78640163f7ef6b41;
extern _jc_method _jc_gnu_java_nio_charset_Provider$method_info$charsetForName$cb2dd1cda930620d;
extern _jc_method _jc_gnu_java_nio_charset_Provider$method_info$charsets$45ae22f55cf2d149;

// Static methods
extern void _jc_gnu_java_nio_charset_Provider$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_nio_charset_Provider$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_gnu_java_nio_charset_Provider$object *_jc_gnu_java_nio_charset_Provider$method$provider$0f461b860b6a7de8(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_nio_charset_Provider$vmethods {
	void	(*addCharset$78640163f7ef6b41)(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *, struct _jc_java_nio_charset_Charset$object *);
	struct _jc_java_nio_charset_Charset$object	*(*charsetForName$cb2dd1cda930620d)(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*charsets$45ae22f55cf2d149)(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *);
};

// Vtable
struct _jc_gnu_java_nio_charset_Provider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_spi_CharsetProvider$vmethods	java_nio_charset_spi_CharsetProvider;
	_jc_gnu_java_nio_charset_Provider$vmethods	gnu_java_nio_charset_Provider;
};

// Vtype
struct _jc_gnu_java_nio_charset_Provider$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_Provider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_Provider$sub_refs {
	struct _jc_java_util_HashMap$object	*canonicalNames;
	struct _jc_java_util_HashMap$object	*charsets;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_Provider$refs {
    _jc_gnu_java_nio_charset_Provider$sub_refs	gnu_java_nio_charset_Provider;
    _jc_java_nio_charset_spi_CharsetProvider$sub_refs	java_nio_charset_spi_CharsetProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_Provider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_Provider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs	java_nio_charset_spi_CharsetProvider;
    _jc_gnu_java_nio_charset_Provider$sub_nonrefs	gnu_java_nio_charset_Provider;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_Provider$object {
	_jc_gnu_java_nio_charset_Provider$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_Provider$vtype	*vtype;
	_jc_gnu_java_nio_charset_Provider$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_Provider$vtype _jc_gnu_java_nio_charset_Provider$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_Provider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_Provider$class_object;

#endif	/* _JC_gnu_java_nio_charset_Provider_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/charset/Provider.h <==
// public final class gnu.java.nio.charset.Provider

// class file dependencies
// @dep_class 5925a6baeb517b4b gnu_java_nio_charset_Provider
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f5e8d54b80f50935 java_nio_charset_spi_CharsetProvider

// header file dependencies
// @dep_header java_nio_charset_spi_CharsetProvider

#include "java/nio/charset/spi/CharsetProvider.h"

#ifndef _JC_gnu_java_nio_charset_Provider_H_
#define _JC_gnu_java_nio_charset_Provider_H_

// Forward structure declarations
struct _jc_gnu_java_nio_charset_Provider$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_Provider$sub_refs	_jc_gnu_java_nio_charset_Provider$sub_refs;
typedef struct _jc_gnu_java_nio_charset_Provider$sub_nonrefs	_jc_gnu_java_nio_charset_Provider$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_Provider$refs	_jc_gnu_java_nio_charset_Provider$refs;
typedef struct _jc_gnu_java_nio_charset_Provider$nonrefs	_jc_gnu_java_nio_charset_Provider$nonrefs;
typedef struct _jc_gnu_java_nio_charset_Provider$object	_jc_gnu_java_nio_charset_Provider$object;

typedef struct _jc_gnu_java_nio_charset_Provider$fields_struct	_jc_gnu_java_nio_charset_Provider$fields_struct;
typedef const struct _jc_gnu_java_nio_charset_Provider$vmethods	_jc_gnu_java_nio_charset_Provider$vmethods;
typedef const struct _jc_gnu_java_nio_charset_Provider$vtable	_jc_gnu_java_nio_charset_Provider$vtable;
typedef const struct _jc_gnu_java_nio_charset_Provider$vtype	_jc_gnu_java_nio_charset_Provider$vtype;

// Class fields structure
struct _jc_gnu_java_nio_charset_Provider$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24nio__24charset__24Provider;
	struct _jc_gnu_java_nio_charset_Provider$object	*singleton;
};
extern _jc_gnu_java_nio_charset_Provider$fields_struct _jc_gnu_java_nio_charset_Provider$class_fields;

// Constructors
extern void _jc_gnu_java_nio_charset_Provider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_nio_charset_Provider$method$addCharset$78640163f7ef6b41(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *, struct _jc_java_nio_charset_Charset$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_charset_Charset$object *_jc_gnu_java_nio_charset_Provider$method$charsetForName$cb2dd1cda930620d(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_nio_charset_Provider$method$charsets$45ae22f55cf2d149(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_charset_Provider$method$loadExtended$b6838af3ba3330cb(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_Provider$method_info$addCharset$78640163f7ef6b41;
extern _jc_method _jc_gnu_java_nio_charset_Provider$method_info$charsetForName$cb2dd1cda930620d;
extern _jc_method _jc_gnu_java_nio_charset_Provider$method_info$charsets$45ae22f55cf2d149;
extern _jc_method _jc_gnu_java_nio_charset_Provider$method_info$loadExtended$b6838af3ba3330cb;

// Static methods
extern void _jc_gnu_java_nio_charset_Provider$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_nio_charset_Provider$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_nio_charset_Provider$object *_jc_gnu_java_nio_charset_Provider$method$provider$0f461b860b6a7de8(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_Provider$vmethods {
	void	(*addCharset$78640163f7ef6b41)(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *, struct _jc_java_nio_charset_Charset$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_charset_Charset$object	*(*charsetForName$cb2dd1cda930620d)(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*charsets$45ae22f55cf2d149)(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *) _JC_JCNI_ATTR;
	void	(*loadExtended$b6838af3ba3330cb)(_jc_env *, struct _jc_gnu_java_nio_charset_Provider$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_charset_Provider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_spi_CharsetProvider$vmethods	java_nio_charset_spi_CharsetProvider;
	_jc_gnu_java_nio_charset_Provider$vmethods	gnu_java_nio_charset_Provider;
};

// Vtype
struct _jc_gnu_java_nio_charset_Provider$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_Provider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_Provider$sub_refs {
	struct _jc_java_util_HashMap$object	*canonicalNames;
	struct _jc_java_util_HashMap$object	*charsets;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_Provider$refs {
    _jc_gnu_java_nio_charset_Provider$sub_refs	gnu_java_nio_charset_Provider;
    _jc_java_nio_charset_spi_CharsetProvider$sub_refs	java_nio_charset_spi_CharsetProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_Provider$sub_nonrefs {
	jboolean	extendedLoaded;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_Provider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs	java_nio_charset_spi_CharsetProvider;
    _jc_gnu_java_nio_charset_Provider$sub_nonrefs	gnu_java_nio_charset_Provider;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_Provider$object {
	_jc_gnu_java_nio_charset_Provider$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_Provider$vtype	*vtype;
	_jc_gnu_java_nio_charset_Provider$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_Provider$vtype _jc_gnu_java_nio_charset_Provider$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_Provider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_Provider$class_object;

#endif	/* _JC_gnu_java_nio_charset_Provider_H_ */
